
/*Citation: Lee, Sangyoul and Xiang Bi. 2019. Can adoption of pollution prevention techniques reduce pollution substitution? Working paper,
Food and resource economics department, University of Florida, Gainesville, U.S.A. */

/* Copyright 2019 by Lee and Bi. */
/*All rights reserved. Readers may make verbatim copies of this document for non-commercial purposes by any means, provided this copyright notice appears on all such copies.*/

clear 
set more off

*change working directory
*cd /Users/xiangbi/Dropbox/PLOSONE/
*reghdfe package needs to be installed from http://scorreia.com/reghdfe.

use dataset_PS_lee_bi.dta, clear 

*describe all will show all variable labels 

*****************************
*Table 1* Summary Statistics
*****************************

su y1b y0b y2b y22b n_ac_corep2 t_afs att_pm att_ozone unemp lnemp produc_ratio h_p2b s_t_afsb

*************************************************************************************************
*Table 2* Fixed-Effects Panel Estimates on Effects of P2 on Pollution Substitutions (1993-2011)
*************************************************************************************************

xtset code year

*Column(1 and 2): This also reports the results of first-stage estimates 
reghdfe y1b l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), stage(first) absorb(i.code i.sicdig2##c.year i.st_fips##c.year) ///
cluster(code), if year>=1993 

*Column(3)
reghdfe y0b l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), absorb(i.code i.sicdig2##c.year i.st_fips##c.year) ///
cluster(code), if year>=1993 

*Column(4)
reghdfe y2b l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), absorb(i.code i.sicdig2##c.year i.st_fips##c.year)  ///
cluster(code), if year>=1993 

***************************************************************************************************************
*Table 3* Fixed-Effects Panel Estimates on Effects on Pollution Substitutions by Types of P2 Techniques(1993-2011)
***************************************************************************************************************


*Column(1)
reghdfe y1b l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.(n_ac_corep2proc n_ac_corep2equip n_ac_corep2mat) = l2.h_p2procb l2.h_p2equipb l2.h_p2matb l2.s_t_afsb), /// 
absorb(i.sicdig2 i.st_fips i.code i.st_fips##c.year i.sicdig2##c.year) cluster(code) ///
, if year>=1993 

*Column(2)
reghdfe y0b l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.(n_ac_corep2proc n_ac_corep2equip n_ac_corep2mat) = l2.h_p2procb l2.h_p2equipb l2.h_p2matb l2.s_t_afsb), /// 
absorb(i.sicdig2 i.st_fips i.code i.st_fips##c.year i.sicdig2##c.year) cluster(code) ///
, if year>=1993 

*Column(3)
reghdfe y2b l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.(n_ac_corep2proc n_ac_corep2equip n_ac_corep2mat) = l2.h_p2procb l2.h_p2equipb l2.h_p2matb l2.s_t_afsb), /// 
absorb(i.sicdig2 i.st_fips i.code i.st_fips##c.year i.sicdig2##c.year) cluster(code) ///
, if year>=1993 

***************************************************************************************************
** Table 4. Repeat table 1 but with additional variable production ratio 
*************************************************************************************************** 

* This analysis is using identification of Table2 (main model) only adding production

*Column(1)
reghdfe y1b l.(t_afs att_pm att_ozone unemp lnemp produc_ratio) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), stage(first) absorb(i.code i.sicdig2##c.year i.st_fips##c.year) ///
cluster(code), if year>=1993 

*Column(2)
reghdfe y0b l.(t_afs att_pm att_ozone unemp lnemp produc_ratio) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), absorb(i.code i.sicdig2##c.year i.st_fips##c.year) ///
cluster(code), if year>=1993 

*Column(3)
reghdfe y2b l.(t_afs att_pm att_ozone unemp lnemp produc_ratio) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), absorb(i.code i.sicdig2##c.year i.st_fips##c.year)  ///
cluster(code), if year>=1993 

*Column(4) offsite recycling within total recycling (omitted from table 4 for brevity)
reghdfe y22b l.(t_afs att_pm att_ozone unemp lnemp produc_ratio) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), absorb(i.code i.sicdig2##c.year i.st_fips##c.year)  ///
cluster(code), if year>=1993 

*************************************************************************************************************************************************
*Table 5* Fixed-Effects Panel Estimates on Effects of P2 on Pollution Substitution Using Cumulative P2 Techniques from Recent Five Years
*************************************************************************************************************************************************


*Column(1)
reghdfe y1b l.(t_afs att_pm att_ozone unemp lnemp) (l.n_ac_corep2_5y = l2.h_p2b l2.s_t_afsb), ///
absorb(i.sicdig2 i.st_fips i.code i.st_fips##c.year i.sicdig2##c.year) cluster(code), if year>=1993

*Column(2)
reghdfe y0b l.(t_afs att_pm att_ozone unemp lnemp) (l.n_ac_corep2_5y = l2.h_p2b l2.s_t_afsb), ///
absorb(i.sicdig2 i.st_fips i.code i.st_fips##c.year i.sicdig2##c.year) cluster(code), if year>=1993

*Column(3)
reghdfe y2b l.(t_afs att_pm att_ozone unemp lnemp) (l.n_ac_corep2_5y = l2.h_p2b l2.s_t_afsb), ///
absorb(i.sicdig2 i.st_fips i.code i.st_fips##c.year i.sicdig2##c.year) cluster(code) stage(first), if year>=1993

*Column(4) offiste recycling within total recycling (omitted from table 5 for brevity)
reghdfe y22b l.(t_afs att_pm att_ozone unemp lnemp) (l.n_ac_corep2_5y = l2.h_p2b l2.s_t_afsb), ///
absorb(i.sicdig2 i.st_fips i.code i.st_fips##c.year i.sicdig2##c.year) cluster(code), if year>=1993

 
***************************************************************************************************
* Table 6* Fixed-Effects Panel Estimates Using Pollutant Levels as Dependent Variables 
***************************************************************************************************


*Column(1)
reghdfe ltreat l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), absorb(i.code i.st_fips##c.year i.sicdig2##c.year) cluster(code) ///
, if year>=1993

*Column(2)
reghdfe lrecycle l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), absorb(i.sicdig2 i.st_fips i.code i.st_fips##c.year i.sicdig2##c.year) cluster(code) ///
, if year>=1993 

*Column(3)
reghdfe ltotal l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), absorb(i.sicdig2 i.st_fips i.code i.st_fips##c.year i.sicdig2##c.year) cluster(code) ///
, if year>=1993 


********************************************************************************************************************
*Table 7* Fixed-Effects Panel Estimates on Effects of P2 on Pollution Substitutions without IVs with production ratio (1993-2011)
********************************************************************************************************************


*Column(1): This also reports the results of first-stage estimates
reghdfe y1b l.(n_ac_corep2 t_afs att_pm att_ozone unemp lnemp produc_ratio) ///
, absorb(i.code i.sicdig2##c.year i.st_fips##c.year) ///
cluster(code), if year>=1993 

*Column(2)
reghdfe y0b l.(n_ac_corep2 t_afs att_pm att_ozone unemp lnemp produc_ratio) ///
, absorb(i.code i.sicdig2##c.year i.st_fips##c.year) ///
cluster(code), if year>=1993 

*Column(3)
reghdfe y2b l.(n_ac_corep2 t_afs att_pm att_ozone unemp lnemp produc_ratio) ///
, absorb(i.code i.sicdig2##c.year i.st_fips##c.year)  ///
cluster(code), if year>=1993 

*Column(4) offsite recycling within total recyling 
reghdfe y22b l.(n_ac_corep2 t_afs att_pm att_ozone unemp lnemp produc_ratio) ///
, absorb(i.code i.sicdig2##c.year i.st_fips##c.year)  ///
cluster(code), if year>=1993 

*******************************************************************************************************
*Appendix Table 1* Effects of P2 on Pollution Substitution with air emission  
*******************************************************************************************************


*Column(1)
reghdfe y1ab l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), stage(first) absorb(i.code i.sicdig2##c.year i.st_fips##c.year) ///
cluster(code), if year>=1993 

*Column(2)
reghdfe y2ab l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), absorb(i.code i.sicdig2##c.year i.st_fips##c.year) ///
cluster(code), if year>=1993 

*Column(3)
reghdfe y22ab l.(t_afs att_pm att_ozone unemp lnemp) ///
(l.n_ac_corep2 = l2.h_p2b l2.s_t_afsb), absorb(i.code i.sicdig2##c.year i.st_fips##c.year)  ///
cluster(code), if year>=1993 

 
